#!/bin/bash
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "run as root now exitting"
   exit 1
fi

export CFLAGS="-mtune=generic -Os -pipe"
export CXXFLAGS="-mtune=generic -Os -pipe"

P=volumeicon
V=0.5.1
SRC=$P-$V
USER=`cat /etc/sysconfig/tcuser`
LIST="compiletc submitqc autoconf automake libtool-dev intltool gettext-dev gtk3-dev alsa-dev  "
for Z in $LIST 
    do 
    su -c "tce-load -i $Z" $USER
done

cd /tmp
su -c "/usr/local/bin/wget -nc --no-check-certificate \
https://github.com/Maato/$P/archive/refs/tags/$V.zip \
https://www.dropbox.com/s/qtc8n71we9ct07h/$P.png" $USER
unzip $V.zip
cd $SRC
./autogen.sh
./autogen.sh autoupdate
# and ignored various warnings
./configure --prefix=/usr/local --disable-oss --disable-notify
make -j5 # seconds
make install-strip DESTDIR=/tmp/$P
cd /tmp

# locale
###########
mkdir -p $P-locale/usr/local/share
mv $P/usr/local/share/locale $P-locale/usr/local/share

# main
######
mkdir -p $P/usr/local/share/doc/$P
echo 'GPL v3' > $P/usr/local/share/doc/$P/COPYING

# desktop - icon
################  convert svg to png using mtpaint not showing here
mkdir -p $P/usr/local/share/pixmaps
mv $P.png  $P/usr/local/share/pixmaps/

# no desktop
mkdir -p $P/usr/local/share/applications
echo '[Desktop Entry]
Name=volumeicon
Exec=volumeicon &
Icon=volumeicon
Terminal=false
X-FullPathIcon=/usr/local/share/pixmaps/volumeicon.png
Type=Application
Categories=Utility; ' > $P/usr/local/share/applications/$P.desktop

# TCZ them
#######
LIST="$P $P-locale"
for Z in $LIST
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo 'Title:          volumeicon-locale.tcz 
Description:    locales for volumeicon
Version:        0.5.1
Author:         various
Original-site:  https://github.com/Maato/volumeicon
Copying-policy: GPL v3 
Size:           4.0K
Extension_by:   you 
Tags:           alsa
Comments:       not tested by me

Change-log:     2023/03/13 Original 0.5.1 on 14x
Current:        2023/03/13 
  ' > $P-locale.tcz.info

cat >> $P.tcz.info <<'EOF'
Title:          volumeicon.tcz 
Description:    alsa volume applet for panels
Version:        0.5.1
Author:         various
Original-site:  https://github.com/Maato/volumeicon
Copying-policy: GPL v3 
Size:           52K
Extension_by:   you 
Tags:           alsa
Comments:       tested on icewm panel
                alsa sound must be set up first please
                applet does not work with wbar.
                For a RH mouse user, left click normally
                mutes master volume
                and right click opens context menu

                Autostart applet add line to existing file,
                its not a script just a file
                $ cat ~/X.d/my-autostarts
                pcmanfm --desktop &
                volumeicon &
                /home/tc/.local/bin/fox &

Change-log:     2023/03/13 Original 0.5.1 on 14x
Current:        2023/03/13 
EOF

# dep check
###########
readelf -d $P/usr/local/bin/volumeicon | grep 'NEEDED'
######################################
# 0x0000000000000001 (NEEDED)  Shared library: [libgtk-3.so.0] gtk3  
# 0x0000000000000001 (NEEDED)  Shared library: [libgdk-3.so.0]  "
# 0x0000000000000001 (NEEDED)  Shared library: [libz.so.1]   TCB
# 0x0000000000000001 (NEEDED)  Shared library: [libpangocairo-1.0.so.0] pango -> gtk3  
# 0x0000000000000001 (NEEDED)  Shared library: [libpango-1.0.so.0]        "       "
# 0x0000000000000001 (NEEDED)  Shared library: [libharfbuzz.so.0]  harfbuzz
# 0x0000000000000001 (NEEDED)  Shared library: [libatk-1.0.so.0]    atk     ->     gtk3
# 0x0000000000000001 (NEEDED)  Shared library: [libcairo-gobject.so.2] cairo       "
# 0x0000000000000001 (NEEDED)  Shared library: [libcairo.so.2]           "
# 0x0000000000000001 (NEEDED)  Shared library: [libgdk_pixbuf-2.0.so.0] gdk-pixbuf2  ->  "
# 0x0000000000000001 (NEEDED)  Shared library: [libgio-2.0.so.0]    glib2             -> "
# 0x0000000000000001 (NEEDED)  Shared library: [libgobject-2.0.so.0] "
# 0x0000000000000001 (NEEDED)  Shared library: [libglib-2.0.so.0]    "
# 0x0000000000000001 (NEEDED)  Shared library: [libasound.so.2]    libasound  alsa
# 0x0000000000000001 (NEEDED)  Shared library: [libX11.so.6]  libX11
# 0x0000000000000001 (NEEDED)  Shared library: [libm.so.6]     main
# 0x0000000000000001 (NEEDED)  Shared library: [libpthread.so.0] "
# 0x0000000000000001 (NEEDED)  Shared library: [libc.so.6]       "
#####################################################################

echo 'gtk3.tcz
harfbuzz.tcz
alsa.tcz
libX11.tcz  ' > $P.tcz.dep

echo 'volumeicon.tcz' > $P-locale.tcz.dep

submitqc --libs
